# PvMail

Watches an EPICS PV and sends email when value changes from 0 to 1.


tag | release | PyPI | conda
--- | --- | --- | ---
[![image](https://img.shields.io/github/tag/BCDA-APS/PvMail.svg)](https://github.com/BCDA-APS/PvMail/tags) |  [![image](https://img.shields.io/github/release/BCDA-APS/PvMail.svg)](https://github.com/BCDA-APS/PvMail/releases) | [![image](https://img.shields.io/pypi/v/PvMail.svg)](https://pypi.python.org/pypi/PvMail/) | --tba--

- copyright:   (c) 2009-2024, UChicago Argonne, LLC
- license: [ANL OPEN SOURCE LICENSE](./src/PvMail/LICENSE)
- documentation: [https://BCDA-APS.github.io/pvMail/](https://BCDA-APS.github.io/pvMail/)
- source: [https://github.com/BCDA-APS/pvMail](https://github.com/BCDA-APS/pvMail)
- authors: Pete R. Jemian, Kurt Goetze